@@ -521,7 +521,7 @@ class MainWindow(qwrappers.WindowWrapper):
 		if not self._tabsContents[index].has_child():
 			tab = self._TAB_CLASS[index](self._app, self._session, self._errorLog)
 			self._tabsContents[index].set_child(tab)
-			self._tabsContents[index].refresh(force=False)
+		self._tabsContents[index].refresh(force=False)
 
 	def _prompt_for_login(self):
 		if self._credentialsDialog is None:
@@ -551,7 +551,10 @@ class MainWindow(qwrappers.WindowWrapper):
 		self._accountDialog.set_callbacks(
 			self._session.get_callback_numbers(), self._session.get_callback_number()
 		)
-		self._accountDialog.accountNumber = self._session.get_account_number()
+		accountNumberToDisplay = self._session.get_account_number()
+		if not accountNumberToDisplay:
+			accountNumberToDisplay = "Not Available (%s)" % self._session.state
+		self._accountDialog.set_account_number(accountNumberToDisplay)
 		response = self._accountDialog.run(self.window)
 		if response == QtGui.QDialog.Accepted:
 			if self._accountDialog.doClear:
@@ -593,6 +596,7 @@ class MainWindow(qwrappers.WindowWrapper):
 
 			for tab in self._tabsContents:
 				tab.enable()
+			self._initialize_tab(self._currentTab)
 
 	@QtCore.pyqtSlot()
 	@misc_utils.log_exception(_moduleLogger)
@@ -659,6 +663,7 @@ class MainWindow(qwrappers.WindowWrapper):
 	@misc_utils.log_exception(_moduleLogger)
 	def _on_account(self, checked = True):
 		with qui_utils.notify_error(self._errorLog):
+			assert self._session.state == self._session.LOGGEDIN_STATE, "Must be logged in for settings"
 			self._show_account_dialog()
 
 
